@@ -17,7 +17,7 @@
 #   
 #   LICENCE
 #   
-#   FMRIB Software Library, Release 4.0 (c) 2007, The University of
+#   FMRIB Software Library, Release 5.0 (c) 2012, The University of
 #   Oxford (the "Software")
 #   
 #   The Software remains the property of the University of Oxford ("the
@@ -66,7 +66,7 @@
 #   interested in using the Software commercially, please contact Isis
 #   Innovation Limited ("Isis"), the technology transfer company of the
 #   University, to negotiate a licence. Contact details are:
-#   innovation@isis.ox.ac.uk quoting reference DE/1112.
+#   innovation@isis.ox.ac.uk quoting reference DE/9564.
 
 #{{{ setups
 
@@ -291,7 +291,7 @@ pack $w.f.opts.gradient $w.f.opts.c -in $w.f.opts.b -side top -anchor w -pady 5
     bind $w.cancel <Return> {
         [winfo toplevel %W].cancel invoke}
  
-    button $w.help -command "FmribWebHelp file: ${FSLDIR}/doc/bet2/index.html" \
+    button $w.help -command "FmribWebHelp file: ${FSLDIR}/doc/redirects/bet.html" \
             -text "Help" -width 5
     bind $w.help <Return> {
         [winfo toplevel %W].help invoke}
