@@ -1,3 +1,9 @@
+/*! \file DiffusionGP.cpp
+    \brief Contains definitions for class for making Gaussian process based predictions about DWI data.
+
+    \author Jesper Andersson
+    \version 1.0b, Sep., 2012.
+*/
 // Definitions of class to make Gaussian-Process
 // based predictions about diffusion data.
 //
@@ -21,14 +27,26 @@
 
 using namespace EDDY;
 
-//@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@
+/////////////////////////////////////////////////////////////////////
 //
 // Class DiffusionGP
 //
-// 
-//
-// {{{ @@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@
+/////////////////////////////////////////////////////////////////////
 
+/****************************************************************//**
+*
+* Constructs a DiffusionGP object given files containing input data.
+* When using this constructor the object is immediately ready to do
+* predictions.
+* \param scans_fname Name of file containing multiple diffusion
+*        weighted volumes.
+* \param var_mask_fname
+* \param dpars Vector of objects of DiffPara type that specifies
+*        diffusion weighting and direction for the volumes in
+*        scans_fname.
+*
+*
+********************************************************************/ 
 DiffusionGP::DiffusionGP(const std::string&            scans_fname,
 			 const std::string&            var_mask_fname,
                          const std::vector<DiffPara>&  dpars)
@@ -39,11 +57,11 @@ DiffusionGP::DiffusionGP(const std::string&            scans_fname,
   _pop = true;
   _dpars = EddyUtils::GetDWIDiffParas(dpars);
   NEWIMAGE::volume<float> var_mask; NEWIMAGE::read_volume(var_mask,var_mask_fname);
-  _vars = VarianceCalculator::GetWMVariances(_sptrs,var_mask,_dpars,_grps,_grpb);
-  _grp = reorganize_grps();
-  _s2n = VarianceCalculator::GetNoiseVariance(_sptrs,var_mask,_dpars);
-  _K = calculate_K();
-  _valid = true;
+  std::vector<std::vector<int> > grps;
+  std::vector<double>            grpb;
+  std::vector<double> vars = VarianceCalculator::GetWMVariances(_sptrs,var_mask,_dpars,grps,grpb);
+  double s2n = VarianceCalculator::GetNoiseVariance(_sptrs,var_mask,_dpars);
+  _gpmod = boost::shared_ptr<GPModel>(new GPModel(_dpars,vars,grps,grpb,s2n));
 }
 
 bool DiffusionGP::IsPopulated() const
@@ -65,12 +83,12 @@ void DiffusionGP::SetNoOfScans(unsigned int n)
     _sptrs.resize(n,boost::shared_ptr<NEWIMAGE::volume<float> >()); // New elements populated by NULL
     _dpars.resize(n); // New elements populated with (arbitrary) [1 0 0] bvec
     _pop = false;
-    _valid = false;
+    _gpmod = boost::shared_ptr<GPModel>();
   }
   else { // If decreasing size
     _sptrs.resize(n);
     _dpars.resize(n);
-    _valid = false;
+    _gpmod = boost::shared_ptr<GPModel>();
     if (_pop==false) { // _pop may potentially go from false to true
       _pop = IsPopulated();
     }
@@ -89,7 +107,7 @@ void DiffusionGP::AddScan(const NEWIMAGE::volume<float>& scan,
   if (_sptrs.size() && !NEWIMAGE::samesize(*_sptrs[0],scan)) throw EddyException("DiffusionGP::AddScan: Wrong image dimension");
   _sptrs.push_back(boost::shared_ptr<NEWIMAGE::volume<float> >(new NEWIMAGE::volume<float>(scan)));
   _dpars.push_back(dp);
-  _valid = false;
+  _gpmod = boost::shared_ptr<GPModel>();
 }
 
 void DiffusionGP::SetScan(const NEWIMAGE::volume<float>& scan,
@@ -103,26 +121,32 @@ void DiffusionGP::SetScan(const NEWIMAGE::volume<float>& scan,
   _dpars[indx] = dp;
 }
 
-void DiffusionGP::UpdateK(const NEWIMAGE::volume<float>& var_mask)
-{
-  if (IsPopulated()) {
-    _vars = VarianceCalculator::GetWMVariances(_sptrs,var_mask,_dpars,_grps,_grpb);
-  _grp = reorganize_grps();
-  _s2n = VarianceCalculator::GetNoiseVariance(_sptrs,var_mask,_dpars);
-  _K = calculate_K();
-  _valid = true;
+void DiffusionGP::EvaluateModel(const NEWIMAGE::volume<float>& mask) 
+{ 
+  if (_gpmod == NULL) {
+    std::vector<std::vector<int> > grps;
+    std::vector<double>            grpb;
+    std::vector<double> vars = VarianceCalculator::GetWMVariances(_sptrs,mask,_dpars,grps,grpb);
+    double s2n = VarianceCalculator::GetNoiseVariance(_sptrs,mask,_dpars);
+    _gpmod = boost::shared_ptr<GPModel>(new GPModel(_dpars,vars,grps,grpb,s2n));
   }
-  else throw EddyException("DiffusionGP::UpdateK: You cannot update K until predictor is fully populated");
 }
 
+/****************************************************************//**
+* \brief Returns prediction for point given by indx with noise variance sigman2.
+*
+* Same as NEWIMAGE::volume<float> DiffusionGP::Predict(unsigned int indx) const
+* except that the noise variance is given as a parameter (rather than
+* using that which is stored in the object).
+* \param sigman2 The noise variance of the data.
+*
+********************************************************************/ 
 NEWIMAGE::volume<float> DiffusionGP::Predict(double       sigman2,
 					     unsigned int indx) const
 {
-  if (!_valid) throw EddyException("DiffusionGP::Predict: invalid predictor");
+  if (_gpmod == NULL) throw EddyException("DiffusionGP::Predict: invalid predictor");
 
-  NEWMAT::RowVector       K_row = extract_K_row(indx);
-  NEWMAT::Matrix          iK = get_iK(sigman2);
-  NEWMAT::RowVector       pvec = K_row*iK;
+  NEWMAT::RowVector       pvec = _gpmod->get_prediction_vector(indx,sigman2);
   NEWMAT::ColumnVector    y(_sptrs.size());
   NEWIMAGE::volume<float> pvol = *_sptrs[0];
   pvol = 0;
@@ -130,9 +154,9 @@ NEWIMAGE::volume<float> DiffusionGP::Predict(double       sigman2,
     for (int j=0; j<_sptrs[0]->ysize(); j++) {
       for (int i=0; i<_sptrs[0]->xsize(); i++) {
 	if (get_y(i,j,k,y)) { 
-	  std::vector<double> ymeans = get_group_means(y);
-          subtract_group_means(ymeans,y);
-	  pvol(i,j,k) = static_cast<float>((pvec*y).AsScalar()) + ymeans[_grp[indx]];
+	  std::vector<double> ymeans = _gpmod->get_group_means(y);
+          _gpmod->subtract_group_means(ymeans,y);
+	  pvol(i,j,k) = static_cast<float>((pvec*y).AsScalar()) + ymeans[_gpmod->Group(indx)];
         }
       }
     }
@@ -140,15 +164,23 @@ NEWIMAGE::volume<float> DiffusionGP::Predict(double       sigman2,
   return(pvol);  
 }
 
+/****************************************************************//**
+* \brief Returns prediction for point with diffusion weighting given by 
+* dpar and with noise variance sigman2.
+*
+* Same as NEWIMAGE::volume<float> DiffusionGP::Predict(const DiffPara& dpar) const
+* except that the noise variance is given as a parameter (rather than
+* using that which is stored in the object).
+* \param sigman2 The noise variance of the data.
+*
+********************************************************************/ 
 NEWIMAGE::volume<float> DiffusionGP::Predict(double            sigman2,
 					     const DiffPara&   dpars) const
 {
-  if (!_valid) throw EddyException("DiffusionGP::Predict: invalid predictor");
+  if (_gpmod == NULL) throw EddyException("DiffusionGP::Predict: invalid predictor");
   printf("DiffusionGP::Predict(DiffPara dp): Not fully implemented yet\n");
 
-  NEWMAT::RowVector       K_row = calculate_K_row(dpars);
-  NEWMAT::Matrix          iK = get_iK(sigman2);
-  NEWMAT::RowVector       pvec = K_row*iK;
+  NEWMAT::RowVector       pvec = _gpmod->get_prediction_vector(dpars,sigman2);
   NEWMAT::ColumnVector    y(_sptrs.size());
   NEWIMAGE::volume<float> pvol = *_sptrs[0];
   pvol = 0.0;
@@ -162,14 +194,24 @@ NEWIMAGE::volume<float> DiffusionGP::Predict(double            sigman2,
   return(pvol);  
 }
 
+/****************************************************************//**
+* \brief Returns prediction for all loaded points with noise variance 
+* sigman2.
+*
+* Same as NEWIMAGE::volume4D<float> DiffusionGP::PredictAll() const
+* except that the noise variance is given as a parameter (rather than
+* using that which is stored in the object).
+* \param sigman2 The noise variance of the data.
+*
+********************************************************************/ 
 NEWIMAGE::volume4D<float> DiffusionGP::PredictAll(double sigman2) const
 {
-  if (!_valid) throw EddyException("DiffusionGP::PredictAll: invalid predictor");
+  if (_gpmod == NULL) throw EddyException("DiffusionGP::PredictAll: invalid predictor");
 
   NEWIMAGE::volume4D<float> pvols(_sptrs[0]->xsize(),_sptrs[0]->ysize(),_sptrs[0]->zsize(),_sptrs.size());
   pvols = 0;
   for (unsigned int i=0; i<_sptrs.size(); i++) {
-    pvols[i] = this->Predict(sigman2,i);
+    pvols[i] = Predict(sigman2,i);
   }
   return(pvols);
 }
@@ -216,35 +258,86 @@ bool DiffusionGP::get_y(// Input
   return(true);
 }
 
-void DiffusionGP::subtract_group_means(// Input
-				       const std::vector<double>& means,
-				       // Input//output
-				       NEWMAT::ColumnVector&      y) const
+//@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@
+//
+// Class GPModel
+//
+//@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@
+
+GPModel::GPModel(const std::vector<DiffPara>&          dpars,
+		 const std::vector<double>             vars,
+		 const std::vector<std::vector<int> >  grps,
+		 const std::vector<double>             grpb,
+		 double                                s2n) 
+: _dpars(dpars), _vars(vars), _grps(grps), _grpb(grpb), _s2n(s2n)
 {
-  for (unsigned int g=0; g<_grps.size(); g++) {
-    for (unsigned int i=0; i<_grps[g].size(); i++) {
-      y(_grps[g][i]+1) -= means[g];
-    }
-  }
-  return;
+  _grp = reorganize_grps();
+  _K = calculate_K();
 }
 
-void DiffusionGP::add_group_means(// Input
-				  const std::vector<double>& means,
-				  // Input//output
-				  NEWMAT::ColumnVector&      y) const
+double GPModel::Predict(unsigned int                indx,
+			const NEWMAT::ColumnVector& yp,
+			double                      sigman2) const
 {
-  for (unsigned int g=0; g<_grps.size(); g++) {
-    for (unsigned int i=0; i<_grps[g].size(); i++) {
-      y(_grps[g][i]+1) += means[g];
-    }
-  }
-  return;
+  if (yp.Nrows() != int(NPoints())) throw EddyException("GPModel::Predict: mismatch between y and GPModel");
+
+  NEWMAT::RowVector       pvec = get_prediction_vector(indx,sigman2);
+  NEWMAT::ColumnVector    y = yp;
+  std::vector<double>     ymeans = get_group_means(y);
+  subtract_group_means(ymeans,y);
+  return((pvec*y).AsScalar() + ymeans[_grp[indx]]);
 }
 
-std::vector<double> DiffusionGP::get_group_means(const NEWMAT::ColumnVector& y) const
+double GPModel::Predict(const DiffPara&             dpars,
+			const NEWMAT::ColumnVector& yp,
+			double                      sigman2) const
 {
-  std::vector<double> means(_grps.size(),0);
+  if (yp.Nrows() != int(NPoints())) throw EddyException("GPModel::Predict: mismatch between y and GPModel");
+
+  NEWMAT::RowVector       pvec = get_prediction_vector(dpars,sigman2);
+
+  // Have to do something about means here.
+
+  NEWMAT::ColumnVector    y = yp;
+  std::vector<double> ymeans = get_group_means(y);
+  subtract_group_means(ymeans,y);
+  return((pvec*y).AsScalar()); //  + ymeans[_grp[indx]]);
+}
+
+NEWMAT::RowVector GPModel::get_prediction_vector(unsigned int indx,
+						 double        sigman2) const
+{
+  NEWMAT::RowVector       K_row = extract_K_row(indx);
+  NEWMAT::Matrix          iK = get_iK(sigman2);
+  NEWMAT::RowVector       pvec = K_row*iK;
+
+  return(pvec);
+}
+
+NEWMAT::RowVector GPModel::get_prediction_vector(const DiffPara& dpars,
+						 double          sigman2) const
+{
+  NEWMAT::RowVector       K_row = calculate_K_row(dpars);
+  NEWMAT::Matrix          iK = get_iK(sigman2);
+  NEWMAT::RowVector       pvec = K_row*iK;
+
+  return(pvec);
+}
+
+std::vector<int> GPModel::reorganize_grps() const
+{
+  std::vector<int> grpi(NPoints());
+  for (unsigned g=0; g<_grps.size(); g++) {
+    for (unsigned int s=0; s<_grps[g].size(); s++) {
+      grpi[_grps[g][s]] = g;
+    }
+  }
+  return(grpi);
+}
+
+std::vector<double> GPModel::get_group_means(const NEWMAT::ColumnVector& y) const
+{
+  std::vector<double> means(NPoints(),0);
 
   for (unsigned int g=0; g<_grps.size(); g++) {
     for (unsigned int i=0; i<_grps[g].size(); i++) {
@@ -255,41 +348,53 @@ std::vector<double> DiffusionGP::get_group_means(const NEWMAT::ColumnVector& y)
   return(means);
 }
 
-std::vector<int> DiffusionGP::reorganize_grps() const
+void GPModel::subtract_group_means(const std::vector<double>& means,
+				   NEWMAT::ColumnVector&      y) const
 {
-  std::vector<int> grpi(_sptrs.size());
-  for (unsigned g=0; g<_grps.size(); g++) {
-    for (unsigned int s=0; s<_grps[g].size(); s++) {
-      grpi[_grps[g][s]] = g;
+  for (unsigned int g=0; g<_grps.size(); g++) {
+    for (unsigned int i=0; i<_grps[g].size(); i++) {
+      y(_grps[g][i]+1) -= means[g];
     }
   }
-  return(grpi);
+  return;
 }
 
-NEWMAT::CroutMatrix DiffusionGP::get_LUK(double sigman2) const
+void GPModel::add_group_means(const std::vector<double>& means,
+			      NEWMAT::ColumnVector&      y) const
 {
-  NEWMAT::IdentityMatrix sn2(_sptrs.size());
-  sn2 *= sigman2;
-  NEWMAT::CroutMatrix LUK = (_K + sn2);
-
-  return(LUK);
+  for (unsigned int g=0; g<_grps.size(); g++) {
+    for (unsigned int i=0; i<_grps[g].size(); i++) {
+      y(_grps[g][i]+1) += means[g];
+    }
+  }
+  return;
 }
 
-NEWMAT::Matrix DiffusionGP::get_iK(double sigman2) const
+NEWMAT::Matrix GPModel::get_iK(double sigman2) const
 {
-  NEWMAT::IdentityMatrix sn2(_sptrs.size());
+  NEWMAT::IdentityMatrix sn2(NPoints());
   sn2 *= sigman2;
   NEWMAT::Matrix iK = (_K + sn2).i();
 
   return(iK);
 }
 
-NEWMAT::Matrix DiffusionGP::calculate_K() const
+/****************************************************************//**
+*
+* This will calculate the K-matrix, i.e. the variance-covariance 
+* matrix of the Gaussian Process. It's form has been empirically
+* derived once and for all, and it depends on two parameters. The
+* variance of the signal (derived from the scan-to-scan white matter
+* variance) and the variance of the noise (derived from the 
+* scan-to-scan variance outside the object).
+*
+********************************************************************/ 
+NEWMAT::Matrix GPModel::calculate_K() const
 {
-  NEWMAT::Matrix K(_sptrs.size(),_sptrs.size());
+  NEWMAT::Matrix K(NPoints(),NPoints());
 
-  for (unsigned int i=0; i<_sptrs.size(); i++) {
-    for (unsigned int j=i; j<_sptrs.size(); j++) {
+  for (unsigned int i=0; i<NPoints(); i++) {
+    for (unsigned int j=i; j<NPoints(); j++) {
       double var = sqrt(_vars[_grp[i]])*sqrt(_vars[_grp[j]]);
       K(i+1,j+1) = 0.54*var + 1.54*var*pow(abs((_dpars[i].bVec().t()*_dpars[j].bVec()).AsScalar()),2.0);
       K(j+1,i+1) = K(i+1,j+1);
@@ -297,16 +402,16 @@ NEWMAT::Matrix DiffusionGP::calculate_K() const
   }
   return(K);
 }
-
-NEWMAT::RowVector DiffusionGP::extract_K_row(unsigned int indx) const
+  
+NEWMAT::RowVector GPModel::extract_K_row(unsigned int indx) const
 {
-  NEWMAT::RowVector  K_row(_sptrs.size());
-  for (unsigned int i=0; i<_sptrs.size(); i++) K_row(i+1) = _K(indx+1,i+1);
+  NEWMAT::RowVector  K_row(NPoints());
+  for (unsigned int i=0; i<NPoints(); i++) K_row(i+1) = _K(indx+1,i+1);
 
   return(K_row);
 }
-
-NEWMAT::RowVector DiffusionGP::calculate_K_row(const DiffPara& dpar) const
+  
+NEWMAT::RowVector GPModel::calculate_K_row(const DiffPara&    dpar) const
 {
   // Check that we have a valid b-value
   unsigned int g;
@@ -314,25 +419,41 @@ NEWMAT::RowVector DiffusionGP::calculate_K_row(const DiffPara& dpar) const
   if (g == _grps.size()) throw EddyException("DiffusionGP::calculate_K_row: bval not in existing shell");
 
   // Make row
-  NEWMAT::RowVector  K_row(_sptrs.size());
-  for (unsigned int i=0; i<_sptrs.size(); i++) {
+  NEWMAT::RowVector  K_row(NPoints());
+  for (unsigned int i=0; i<NPoints(); i++) {
     double var = sqrt(_vars[g])*sqrt(_vars[_grp[i]]);
     K_row(i+1) = 0.54*var + 1.54*var*pow(abs((_dpars[i].bVec().t()*dpar.bVec()).AsScalar()),2.0);
   }
   return(K_row);
-} 
-
-// }}} End of fold.
-
+}
 
 //@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@
 //
 // Class VarianceCalculator
 //
-// 
-//
-// {{{ @@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@
+//@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@
 
+/****************************************************************//**
+*
+* Static member function that calculates the (signal) variance 
+* (across scans) in white matter.
+* First it will divide the input data into "groups" corresponding
+* to shells (sets of scans with similar b-values). 
+* Secondly it uses the supplied mask as an indicator where the object 
+* (brain) is.
+* Finally for each group it calculates the across scan variance for 
+* all voxels within the object and the find the 20% of those with the 
+* highest variance (assuming these to be high FA white matter voxels).
+* The average of thos 20% will be returned for each of the groups.
+* \param[in] sprts Vector of (safe) pointers to dwi scans.
+* \param[in] mask Volume with ones where the object (brain) is.
+* \param[in] dpars Vector of diffusion paramaters for sprts
+* \param[out] grps Vector (length of # of groups) of vectors
+* (with indicies into scans beloning to that group).
+* \param[out] grpb Vector of (average) b-values for each group.
+* \return Vector of white matter variances for each group. 
+*
+********************************************************************/ 
 std::vector<double> VarianceCalculator::GetWMVariances(// Input
 						       const std::vector<boost::shared_ptr<NEWIMAGE::volume<float> > >&   sptrs,
 						       const NEWIMAGE::volume<float>&                                     mask,
@@ -364,6 +485,22 @@ std::vector<double> VarianceCalculator::GetWMVariances(// Input
   return(var);
 }
 
+/****************************************************************//**
+*
+* Static member function that calculates the (noise) variance 
+* (across scans) in an area outside the object (brain).
+* First it uses the supplied mask as an indicator (that is made more
+* conservative by some dilates) where the object (brain) is.
+* Finally for each group it calculates the across scan variance for 
+* all voxels within the object and the find the 20% of those with the 
+* highest variance (assuming these to be high FA white matter voxels).
+* The average of thos 20% will be returned for each of the groups.
+* \param[in] sprts Vector of (safe) pointers to dwi scans.
+* \param[in] mask Volume with ones where the object (brain) is.
+* \param[in] dpars Vector of diffusion paramaters for sprts
+* \return Vector of white matter variances for each group. 
+*
+********************************************************************/ 
 double VarianceCalculator::GetNoiseVariance(// Input
 					    const std::vector<boost::shared_ptr<NEWIMAGE::volume<float> > >&   sptrs,
 					    const NEWIMAGE::volume<float>&                                     mask,
