@@ -91,6 +91,12 @@ NEWIMAGE::volume4D<float> ECScan::field_for_model_to_scan_transform(// Input
   return(idfield);
 }
 
+/*!
+ * Returns the original (unsmoothed) image transformed into model space, i.e. undistorted space.
+ * \param[in] susc (Safe) pointer to a susceptibility field (in Hz).
+ * \param[out] omask Mask indicating valid voxels (voxels that fall within the original image).
+ * \return Original (unsmoothed) image transformed into model space, i.e. undistorted space.
+ */
 NEWIMAGE::volume<float> ECScan::GetUnwarpedOriginalIma(// Input
 						       boost::shared_ptr<const NEWIMAGE::volume<float> >   susc,
 						       // Output
@@ -98,13 +104,23 @@ NEWIMAGE::volume<float> ECScan::GetUnwarpedOriginalIma(// Input
 {
   return(transform_to_model_space(this->GetOriginalIma(),susc,omask)); 
 }
+/*!
+ * Returns the original (unsmoothed) image transformed into model space, i.e. undistorted space.
+ * \param[in] susc (Safe) pointer to a susceptibility field (in Hz).
+ * \return Original (unsmoothed) image transformed into model space, i.e. undistorted space.
+ */
 NEWIMAGE::volume<float> ECScan::GetUnwarpedOriginalIma(// Input
 						       boost::shared_ptr<const NEWIMAGE::volume<float> >   susc) const
 { 
   NEWIMAGE::volume<float> skrutt = this->GetOriginalIma(); skrutt = 0.0;
   return(transform_to_model_space(this->GetOriginalIma(),susc,skrutt)); 
 }
-
+/*!
+ * Returns the smoothed image transformed into model space, i.e. undistorted space.
+ * \param[in] susc (Safe) pointer to a susceptibility field (in Hz).
+ * \param[out] omask Mask indicating valid voxels (voxels that fall within the original image).
+ * \return Smoothed image transformed into model space, i.e. undistorted space.
+ */
 NEWIMAGE::volume<float> ECScan::GetUnwarpedIma(// Input
 					       boost::shared_ptr<const NEWIMAGE::volume<float> >   susc,
 					       // Output
@@ -112,13 +128,25 @@ NEWIMAGE::volume<float> ECScan::GetUnwarpedIma(// Input
 {
   return(transform_to_model_space(this->GetIma(),susc,omask)); 
 }
+/*!
+ * Returns the smoothed image transformed into model space, i.e. undistorted space.
+ * \param[in] susc (Safe) pointer to a susceptibility field (in Hz).
+ * \return Smoothed image transformed into model space, i.e. undistorted space.
+ */
 NEWIMAGE::volume<float> ECScan::GetUnwarpedIma(// Input
 					       boost::shared_ptr<const NEWIMAGE::volume<float> >   susc) const
 { 
   NEWIMAGE::volume<float> skrutt = this->GetIma(); skrutt = 0.0;
   return(transform_to_model_space(this->GetIma(),susc,skrutt)); 
 }
-
+/*!
+ * Returns a vector with translations (in mm) resulting from a 
+ * field of 1Hz. If for example the scan has been acquired with
+ * positive phase-encode blips in the x-direction it will return
+ * a vector with a positive value in the first element and zero
+ * in the other two elements.
+ * \return A 3x1 vector with translations (in mm)
+ */
 NEWMAT::ColumnVector ECScan::GetHz2mmVector() const
 {
   NEWMAT::ColumnVector hz2mm(3);
@@ -136,6 +164,13 @@ void ECScan::SetFWHM(double fwhm)
   else { _sima = NEWIMAGE::smooth(_ima,fwhm/std::sqrt(8.0*std::log(2.0))); _fwhm = fwhm; return; }
 }
 
+/*!
+ * Routine that replaces selected (from ol) slices from a replacement volume (rep) for valid voxels (given by inmask). Used as part of outlier detection and replacement. Hence the rep volume is typically a predicted volume.
+ * \param[in] rep The volume from which to pick slices to replace those in _ima with. This would typically be a prediction on model space.
+ * \param[in] susc Susceptibilty induced off-resonance field (Hz)
+ * \param[in] inmask Mask that indicates what voxels in rep are valid. Should be in same space as rep, typically model space.
+ * \param[in] ol Vector of indicies (zero-offset) indicating which slices to replace.
+ */
 void ECScan::ReplaceSlices(const NEWIMAGE::volume<float>&                     rep,
 			   boost::shared_ptr<const NEWIMAGE::volume<float> >  susc,
 			   const NEWIMAGE::volume<float>&                     inmask, 
@@ -197,6 +232,20 @@ NEWIMAGE::volume<float> ECScan::transform_to_model_space(// Input
   return(jac*ovol);
 }
 
+/*!
+ * Constructor for the ECScanManager class.
+ * \param imafname Name of 4D file with diffusion weighted and b=0 images.
+ * \param maskfname Name of image file with mask indicating brain (one) and non-brain (zero).
+ * \param acqpfname Name of text file with acquisition parameters.
+ * \param topupfname Basename for topup output.
+ * \param bvecsfname Name of file containing diffusion gradient direction vectors.
+ * \param bvalsfname Name of file containing b-values.
+ * \param ecmodel Enumerated value specifying what EC-model to use.
+ * \param indicies Vector of indicies so that indicies[i] specifies what row in
+ * the acqpfname file corresponds to scan i (zero-offset).
+ * \param sess Vector of session numbers for each of the scans in imafname. The session numbers should be in the range 1--no_of_sessions.
+ * \param no_of_sessions Number of sessions in which data was acquired.
+ */
 ECScanManager::ECScanManager(const std::string&               imafname,
 			     const std::string&               maskfname,
 			     const std::string&               acqpfname,
@@ -295,6 +344,13 @@ unsigned int ECScanManager::NLSRPairs(ScanType st) const
   return(rval);
 }
 
+/*!
+ * Returns the mapping between the "type-specific" DWI indexing and the 
+ * "global" indexing. The latter also corresponding to the indexing
+ * on disc.
+ * \return A vector of indicies. The length of the vector is NScans(DWI)
+ * and rval[i-1] gives the global index of the i'th dwi scan.
+ */
 std::vector<unsigned int> ECScanManager::GetDwi2GlobalIndexMapping() const
 {
   std::vector<unsigned int> i2i(_scans.size());
@@ -304,6 +360,37 @@ std::vector<unsigned int> ECScanManager::GetDwi2GlobalIndexMapping() const
   return(i2i);
 }
 
+/*!
+ * Returns the mapping between the "type-specific" b0 indexing and the 
+ * "global" indexing. The latter also corresponding to the indexing
+ * on disc.
+ * \return A vector of indicies. The length of the vector is NScans(b0)
+ * and rval[i-1] gives the global index of the i'th b0 scan.
+ */
+std::vector<unsigned int> ECScanManager::Getb02GlobalIndexMapping() const
+{
+  std::vector<unsigned int> i2i(_b0scans.size());
+  for (unsigned int i=0; i<_fi.size(); i++) {
+    if (_fi[i].first) i2i[_fi[i].second] = i;
+  }
+  return(i2i);
+}
+
+/*!
+ * Will return true if there are "sufficient" b=0 scans "sufficiently"
+ * interspersed so that the movement parameters from these can help in
+ * separating field offset from "true" movements. The ""s are there to
+ * indicate the arbitrariness of the code, and that it might need to be
+ * revisited based on empricial experience.
+ */
+bool ECScanManager::B0sAreInterspersed() const
+{
+  unsigned int nall = NScans();
+  std::vector<unsigned int> b02g = Getb02GlobalIndexMapping();
+  if (b02g.size() > 2 && b02g[0] < 0.25*nall && b02g.back() > 0.75*nall) return(true);
+  else return(false);
+}
+
 std::pair<unsigned int,unsigned int> ECScanManager::GetLSRPair(unsigned int i, ScanType st) const
 {
   std::pair<unsigned int,unsigned int> rval(0,0);
@@ -446,18 +533,74 @@ NEWIMAGE::volume<float> ECScanManager::GetUnwarpedScan(unsigned int
   return(Scan(indx,st).GetUnwarpedIma(_topup_field,omask)); 
 }
 
-void ECScanManager::SeparateFieldOffsetFromMovement()
+/*!
+ * This function attempts to distinguish between actual subject movement and
+ * things that appear as such. The latter can be for example a field-offset
+ * caused by the scanner iso-centre not coinciding with the centre of the 
+ * image FOV and field drifts caused by temprature changes.
+ *
+ * It starts by extracting everything that can potentially be explained 
+ * as a field offset and putting this into a single vector (one value
+ * per scan) that is scaled in Hz. It does this through a call to 
+ * hz_vector_with_everything(). Let us denote this vector by \f$\mathbf{y}\f$
+ *
+ * As a second step it will create a "design matrix" which (typically) consists of
+ * three columns which are the parameters (slopes) of the linear part of 
+ * the EC field and a set of columns that model linear (with time) drift 
+ * of the field as a consequence of temprature drift. Let us denote this
+ * matrix by \f$\mathbf{X}\f$.
+ *
+ * The third step consists of modelling \f$\mathbf{y}\f$ by \f$\mathbf{X}\f$
+ * so that the residuals (i.e. the unexplained part) becomes the new estimate
+ * of the translations, i.e. \f$\mathbf{p}=(\mathbf{y}-\mathbf{X}\mathbf{X}^+\mathbf{y})\mathbf{h}^T\f$
+ * where \f$\mathbf{X}^+\f$ denotes the pseudo-inverse of \f$\mathbf{X}\f$ and where
+ * \f$\mathbf{h}\f$ is a column-vector translating a (spatially constant) off-resonance 
+ * field into translations (in mm).
+ */
+void ECScanManager::SeparateFieldOffsetFromMovement(EDDY::HzModel m)
 {
-  if (HasFieldOffset()) {
+  bool debug = false;
+
+  if (HasFieldOffset()) { // Only an issue of offset has been modeled
+    if (debug) {
+      cout << "Entered SeparateFieldOffsetFromMovement with model ";
+      if (m == ModelMovements) cout << "ModelMovements" << endl;
+      else cout << "ModelOffset" << endl;
+    }
     // Put everything that can be offset into offset vector
+    if (debug) cout << "Calling hz_vector_with_everything" << endl;
     NEWMAT::ColumnVector hz = hz_vector_with_everything();
-    // Get design explaining offset as off-iso-centre + linear with time
-    NEWMAT::Matrix X = offset_design_matrix();
-    // Get explained component for reintroduction to offset
-    NEWMAT::ColumnVector offset = (X*MISCMATHS::pinv(X))*hz;
-    // Reintroduce explained component
+    if (debug) {
+    cout << "Writing hz-vector for debugging purposes" << endl;
+    MISCMATHS::write_ascii_matrix("hz_vector_for_debugging.txt",hz); 
+    }
+    // Get design explaining movements/offset.
+    NEWMAT::Matrix X;
+    NEWMAT::ColumnVector offset; 
+    NEWMAT::ColumnVector mov_in_hz; 
+    if (m == EDDY::ModelMovements) {
+      if (debug) cout << "Calling movement_design_matrix" << endl;
+      X = movement_design_matrix(debug);
+      mov_in_hz = (X*MISCMATHS::pinv(X))*hz;
+      offset = hz - mov_in_hz;
+    }
+    else { // means that m == ModelOffset
+      if (debug) cout << "Calling offset_design_matrix" << endl;
+      X = offset_design_matrix(debug);
+      offset = (X*MISCMATHS::pinv(X))*hz;
+      mov_in_hz = hz - offset;
+    }
+    if (debug) {
+      cout << "Writing offset/movement design matrix for debugging purposes" << endl;
+      std::string fname = "offset_design_matrix_for_debugging.txt";
+      if (m == EDDY::ModelMovements) fname = "movement_design_matrix_for_debugging.txt";
+      MISCMATHS::write_ascii_matrix(fname,X);
+    }
+    // Reintroduce separated components
+    if (debug) cout << "Adjusting field offsets" << endl;
     for (unsigned int i=0; i<NScans(DWI); i++) Scan(i,DWI).SetFieldOffset(offset(i+1));
     // Adjust movement component accordingly
+    if (debug) cout << "Adjusting movements" << endl;
     for (unsigned int i=0; i<NScans(DWI); i++) {
       NEWMAT::ColumnVector ymm = Scan(i,DWI).GetParams(EDDY::MOVEMENT);
       for (int j=1; j<=3; j++) {
@@ -492,8 +635,105 @@ void ECScanManager::WriteECFields(const std::string& fname, ScanType st) const
   NEWIMAGE::write_volume4D(ovol,fname);
 }
 
-NEWMAT::Matrix ECScanManager::offset_design_matrix() const
+void ECScanManager::WriteOutlierFreeData(const std::string& fname, ScanType st) const
 {
+  NEWIMAGE::volume4D<float> ovol(Scan(0,st).GetOriginalIma().xsize(),Scan(0,st).GetIma().ysize(),Scan(0,st).GetIma().zsize(),NScans(st));
+  NEWIMAGE::copybasicproperties(Scan(0,st).GetOriginalIma(),ovol);
+  for (unsigned int i=0; i<NScans(st); i++) {
+    NEWIMAGE::volume<float> tmp = Scan(i,st).GetOriginalIma() / ScaleFactor();
+    {
+      ovol[i] = tmp;
+    }
+  }
+  NEWIMAGE::write_volume4D(ovol,fname);
+}
+
+/*!
+ * Creates a "design matrix" that allows us to divide the "hz vector" into the part
+ * that can be explained as movement and the part that cannot be explained (and that 
+ * we will therefore assume is offset).
+ * The design will consist of a three-dimensional sub-space of the space spanned by
+ * the movement parameters that do not coincide with the translations in the PE
+ * direction (three rotations and one or two translations). This is predicated on
+ * my experience that in reality the dof of rigid body movement is less than six.
+ *
+ * The difference between this routine and offset_design_matrix is that here we 
+ * try to find all the movment that can be explained by the other movement parameters,
+ * and then assume that the remainder is offset.
+ * In offset_design_matrix we will instead attempt to find all the offset that 
+ * can be explained (by EC) and then we assume that the remainder is movement.
+ *
+ * \return An Nxm design matrix where N is the number of DWIs and m will depend on 
+ * the ScanECModel and the number of sessions.
+ */
+NEWMAT::Matrix ECScanManager::movement_design_matrix(bool debug) const
+{
+  // Make an initial design from b-vecs that have
+  // been mean-corrected on a per sessions basis
+  NEWMAT::Matrix X1(NScans(DWI),3);
+  for (unsigned int i=0; i<NScans(DWI); i++) {  // Make raw matrix
+    X1.Row(i+1) = Scan(i,DWI).GetDiffPara().bVec().t();
+  }
+  for (unsigned int s=0; s<NoOfSessions(); s++) { // Do the mean-correction
+    NEWMAT::RowVector smean(3); smean = 0.0;
+    unsigned int cnt = 0;
+    for (unsigned int i=0; i<NScans(DWI); i++) {
+      if (Scan(i,DWI).Session() == s) { smean += X1.Row(i+1); cnt++; }
+    }
+    smean /= double(cnt);
+    for (unsigned int i=0; i<NScans(DWI); i++) {
+      if (Scan(i,DWI).Session() == s) X1.Row(i+1) -= smean;
+    }
+  } 
+  // Next collect the movement parameters excepting
+  // translations in the PE direction.
+  NEWMAT::Matrix X2(NScans(DWI),6);
+  for (unsigned int i=0; i<NScans(DWI); i++) {
+    X2.Row(i+1) = Scan(i,DWI).GetParams(EDDY::MOVEMENT).t();
+  }
+  if (HasPEinXandY()) X2 = X2.Columns(3,6);
+  else if (HasPEinX()) X2 = X2.Columns(2,6);
+  else if (HasPEinY()) X2 = X2.Column(1) | X2.Columns(3,6);
+  // Now regress bvec-matrix out of each of these.
+  NEWMAT::CroutMatrix luX1 = X1;
+  for (int i=1; i<= X2.Ncols(); i++) {
+    X2.Column(i) -= X1*(luX1.i()*X2.Column(i));
+  }
+  // Take the first 3 singular vectors as design
+  // for the movement parameters.
+  NEWMAT::DiagonalMatrix S(X2.Ncols());
+  NEWMAT::Matrix V(X2.Ncols(),X2.Ncols());
+  NEWMAT::SVD(X2,S,X2,V);
+  X2 = X2.Columns(1,3);
+  // Add interpolated movement parameters
+  // from the b=0 scans.
+  if (B0sAreInterspersed()) {
+    X2 = X2 | get_b0_movement_vector();
+  }
+  return(X2);
+}
+
+/*!
+ * Creates a "design matrix" that allows us to divide the "hz vector" into the part
+ * that can be explained as field offset and or scanner drift and the part that
+ * cannot be explained (and that we will therefore assume is subject movement).
+ * Typically the three first columns will consist of the linear (slopes) part of the 
+ * EC-field for each scan. There will be another n columns where n is 1 if the 
+ * number of sessions is one and number_of_sessions+1 if the number of sessions
+ * is greater than 1.
+ *
+ * The difference between this routine and movement_design_matrix is that here we 
+ * attempt to find all the offset that can be explained (by EC) and then we assume
+ * that the remainder is movement. In movement_design_matrix we will instead try 
+ * to find all the movment that can be explained by the other movement parameters,
+ * and then assume that the remainder is offset.
+ *
+ * \return An Nxm design matrix where N is the number of DWIs and m will depend on 
+ * the ScanECModel and the number of sessions.
+ */
+NEWMAT::Matrix ECScanManager::offset_design_matrix(bool debug) const
+{
+  if (debug) cout << "Building first part" << endl;
   // First build part where we model it as an offset for the linear parameters
   NEWMAT::Matrix offset_part;
   NEWMAT::RowVector test = Scan(0,DWI).GetLinearParameters();
@@ -505,29 +745,53 @@ NEWMAT::Matrix ECScanManager::offset_design_matrix() const
   }
   // Secondly add the linear (with time) part from gradient heating
   // Build one regressor per session to model within session heating.
+  if (debug) cout << "Adding linear part" << endl;
   NEWMAT::Matrix linear_part;
+  if (debug) cout << "Resizing linear part" << endl;
   if (NoOfSessions()>1) linear_part.ReSize(NScans(DWI),NoOfSessions()+1); 
   else linear_part.ReSize(NScans(DWI),1); 
+  if (debug) cout << "Initialising linear part" << endl;
   linear_part = 0.0;
   for (unsigned int i=0; i<NScans(DWI); i++) {
-    linear_part(i+1,Scan(i,DWI).Session()) = linear_part.Column(Scan(i,DWI).Session()).Maximum()+1;
+    if (debug) cout << "i = " << i << ", Scan(i,DWI).Session() = " << Scan(i,DWI).Session() << endl;
+    linear_part(i+1,Scan(i,DWI).Session()+1) = linear_part.Column(Scan(i,DWI).Session()+1).Maximum()+1;
   }
   // 3rd pass to put in linear regressors across all scans (residual heating between sessions)
+  if (debug) cout << "Third pass" << endl;
   if (NoOfSessions()>1) { for (unsigned int i=0; i<NScans(DWI); i++) linear_part(i+1,NoOfSessions()+1) = double(i); }
   // Rescale them to make matrix better conditioned
+  if (debug) cout << "Rescale to condition" << endl;
   for (int i=0; i<linear_part.Ncols(); i++) {
     linear_part.Column(i+1) /= linear_part.Column(i+1).Maximum();
   }
   
+  if (debug) cout << "Concatenate different parts" << endl;
   NEWMAT::Matrix design_matrix;
   if (test.Ncols()) design_matrix = offset_part | linear_part;
   else design_matrix = linear_part;
 
-  MISCMATHS::write_ascii_matrix(string("design_matrix_for_debugging.txt"),design_matrix);
+  if (debug) {
+    cout << "Write for debug" << endl;
+    MISCMATHS::write_ascii_matrix(string("offset_design_matrix_for_debugging.txt"),design_matrix);
+  }
 
   return(design_matrix);
 }
 
+/*!
+ * This function extracts everything that can possibly be an offset,
+ * i.e. a non-zero mean of a field, as one value (the offset or DC
+ * component) per DWI scan (in Hz). At the first level the offset and 
+ * movement (typically the x- and or y- translation) are modeled
+ * separately, but the reality is that those estimates will be 
+ * highly correlated. Let's say that we have an acquisition with
+ * PE in the y-direction then any DC field will look very similar
+ * to a translation in the y-direction so for a given scan it is
+ * almost random if it will be modeled as one or the other. This 
+ * routine will collect anything that can potentially be an offset
+ * and collects it to a single number (offset) per DWI scan.
+ \return A vector with one value (field offset in Hz) per DWI scan.
+ */
 NEWMAT::ColumnVector ECScanManager::hz_vector_with_everything() const
 {
   NEWMAT::ColumnVector hz(NScans(DWI));
@@ -539,6 +803,13 @@ NEWMAT::ColumnVector ECScanManager::hz_vector_with_everything() const
   return(hz);
 }
 
+NEWMAT::Matrix ECScanManager::get_b0_movement_vector(ScanType st) const
+{
+  NEWMAT::Matrix skrutt;
+  throw EddyException("get_b0_movement_vector: Not yet implemented");
+  return(skrutt);
+}
+
 void ECScanManager::set_reference(unsigned int ref,
 				  ScanType     st)
 {
@@ -603,3 +874,11 @@ void ECScanManager::write_lsr_registered_images(const std::string& fname, ScanTy
   NEWIMAGE::write_volume4D(ovol,fname);    
 }
 
+bool ECScanManager::has_pe_in_direction(unsigned int dir, ScanType st) const
+{
+  if (dir != 1 && dir != 2) throw EddyException("ECScanManager::has_pe_in_direction: index out of range");
+  for (unsigned int i=0; i<NScans(st); i++) {
+    if (Scan(i,st).GetDiffPara().bVec()(dir)) return(true);
+  }
+  return(false);
+}
