@@ -15,7 +15,7 @@
     
     LICENCE
     
-    FMRIB Software Library, Release 4.0 (c) 2007, The University of
+    FMRIB Software Library, Release 5.0 (c) 2012, The University of
     Oxford (the "Software")
     
     The Software remains the property of the University of Oxford ("the
@@ -64,7 +64,7 @@
     interested in using the Software commercially, please contact Isis
     Innovation Limited ("Isis"), the technology transfer company of the
     University, to negotiate a licence. Contact details are:
-    innovation@isis.ox.ac.uk quoting reference DE/1112. */
+    innovation@isis.ox.ac.uk quoting reference DE/9564. */
 
 #include "noisemodel.h"
 #include "dist_gamma.h"
@@ -126,7 +126,8 @@ class WhiteNoiseModel : public NoiseModel {
   	const MVNDist& thetaPrior,
   	const LinearFwdModel& model,
         const ColumnVector& data,
-        MVNDist* thetaWithoutPrior = NULL
+    MVNDist* thetaWithoutPrior = NULL,
+        float LMalpha = 0
     ) const;
 
   virtual double CalcFreeEnergy(
