@@ -1,4 +1,4 @@
-/*  glimGls.h
+ /*  glimGls.h
 
     Mark Woolrich and Matthew Webster, FMRIB Image Analysis Group
 
@@ -77,7 +77,6 @@
 #include "newimage/newimageall.h"
 #include "fslsurface/fslsurfaceio.h"
 
-
 using namespace NEWMAT;
 
 namespace FILM {
@@ -87,30 +86,31 @@ namespace FILM {
   class GlimGls
     {
     public:
-      GlimGls(const int pnumTS, const int psizeTS, const int pnumParams);
+      GlimGls(const int pnumTS, const int psizeTS, const int pnumParams, const int pnContrasts, const int pnFContrasts);
      
-      void setData(const ColumnVector& p_y, const Matrix& p_x, const int ind);       
+      void setData(const ColumnVector& p_y, const Matrix& p_x, const int ind, const Matrix& tContrasts, const Matrix& fContrasts);       
       void Save(const NEWIMAGE::volume<float>& mask, NEWIMAGE::volume4D<float>& saveVolume,fslsurface_name::fslSurface<float, unsigned int>& saveSurface,const string& saveMode,const float reftdim=1.0);
       void saveData(const string& outputName, const Matrix& data, NEWIMAGE::volume4D<float>& saveVolume, const NEWIMAGE::volume<float>& volumeMask, const  bool setVolumeRange, const bool setVolumeTdim, const int outputTdim, const bool setIntent, const int intentCode,  fslsurface_name::fslSurface<float, unsigned int>& saveSurface, const string& saveToVolume);
-
-
       ColumnVector& getResiduals() { return r; }
       void CleanUp();
 
     private:
 
-      void SetCorrection(const Matrix& corr, const int ind);
-
       GlimGls(const GlimGls&);
       GlimGls& operator=(const GlimGls& p_glimgls);
    
       int numTS;
       int sizeTS;
+      int nContrasts;
+      int nFContrasts;
+      vector<int> fDof;
       int numParams;
 
       // Data to be saved:
-      Matrix corrections;
       Matrix b;
+      Matrix copes;
+      Matrix varcopes;
+      Matrix fstats;
       RowVector sigmaSquareds;
       float dof;
       ColumnVector r;
