@@ -4,7 +4,69 @@
 //
 // Jesper Andersson, FMRIB Image Analysis Group
 //
-//
+/*    Copyright (C) 2012 University of Oxford  */
+
+/*  Part of FSL - FMRIB's Software Library
+    http://www.fmrib.ox.ac.uk/fsl
+    fsl@fmrib.ox.ac.uk
+    
+    Developed at FMRIB (Oxford Centre for Functional Magnetic Resonance
+    Imaging of the Brain), Department of Clinical Neurology, Oxford
+    University, Oxford, UK
+    
+    
+    LICENCE
+    
+    FMRIB Software Library, Release 5.0 (c) 2012, The University of
+    Oxford (the "Software")
+    
+    The Software remains the property of the University of Oxford ("the
+    University").
+    
+    The Software is distributed "AS IS" under this Licence solely for
+    non-commercial use in the hope that it will be useful, but in order
+    that the University as a charitable foundation protects its assets for
+    the benefit of its educational and research purposes, the University
+    makes clear that no condition is made or to be implied, nor is any
+    warranty given or to be implied, as to the accuracy of the Software,
+    or that it will be suitable for any particular purpose or for use
+    under any specific conditions. Furthermore, the University disclaims
+    all responsibility for the use which is made of the Software. It
+    further disclaims any liability for the outcomes arising from using
+    the Software.
+    
+    The Licensee agrees to indemnify the University and hold the
+    University harmless from and against any and all claims, damages and
+    liabilities asserted by third parties (including claims for
+    negligence) which arise directly or indirectly from the use of the
+    Software or the sale of any products based on the Software.
+    
+    No part of the Software may be reproduced, modified, transmitted or
+    transferred in any form or by any means, electronic or mechanical,
+    without the express permission of the University. The permission of
+    the University is not required if the said reproduction, modification,
+    transmission or transference is done without financial return, the
+    conditions of this Licence are imposed upon the receiver of the
+    product, and all original and amended source code is included in any
+    transmitted product. You may be held legally responsible for any
+    copyright infringement that is caused or encouraged by your failure to
+    abide by these terms and conditions.
+    
+    You are not permitted under this Licence to use this Software
+    commercially. Use for which any financial return is received shall be
+    defined as commercial use, and includes (1) integration of all or part
+    of the source code or the Software into a product for sale or license
+    by or on behalf of Licensee to third parties or (2) use of the
+    Software or any derivative of it for research with the final aim of
+    developing software products for sale or license to a third party or
+    (3) use of the Software or any derivative of it for research with the
+    final aim of developing non-software products for sale or license to a
+    third party, or (4) use of the Software to provide any service to an
+    external organisation for which payment is received. If you are
+    interested in using the Software commercially, please contact Isis
+    Innovation Limited ("Isis"), the technology transfer company of the
+    University, to negotiate a licence. Contact details are:
+    innovation@isis.ox.ac.uk quoting reference DE/9564. */
 
 #include <cstdlib>
 #include <iostream>
@@ -15,9 +77,13 @@
 #include <boost/shared_ptr.hpp>
 #include "newmat.h"
 #include "newmatio.h"
+#ifndef EXPOSE_TREACHEROUS
+#define EXPOSE_TREACHEROUS           // To allow us to use .set_sform etc
+#endif
 #include "newimage/newimageall.h"
 #include "miscmaths/miscmaths.h"
 #include "miscmaths/nonlin.h"
+#include "warpfns/warpfns.h"
 #include "basisfield/basisfield.h"
 #include "basisfield/splinefield.h"
 #include "basisfield/dctfield.h"
@@ -70,7 +136,7 @@ int main(int   argc,
       cerr << "Error occurred when writing results of registration to self" << endl;
       cerr << "Exception thrown with message: " << error.what() << endl; 
     }
-    if (clp->Verbose()) cerr << "Input to fnirt was two identical images. Result is unity transform" << endl;
+    if (clp->Verbose()) cout << "Input to fnirt was two identical images. Result is unity transform." << endl;
     exit(EXIT_SUCCESS);  // Sort of
   }
 
@@ -84,19 +150,17 @@ int main(int   argc,
     if (clp->UseRefMask(1)) refmask = make_mask(clp->RefMask(),InclusiveMask,*ref,clp->UseImplicitRefMask(),clp->ImplicitRefValue());
     else refmask = make_mask(clp->RefMask(),IgnoreMask,*ref,clp->UseImplicitRefMask(),clp->ImplicitRefValue());
 
-    // Normalise ref global mean to 100
+    // Normalise ref and obj global mean to 100
     double refmean = spmlike_mean(*ref);
+    objmean = spmlike_mean(*obj);
     (*ref) *= (100.0/refmean);     
+    (*obj) *= (100.0/objmean);          
 
     // Create objmask as a combination of explicit and implicit masks.
     boost::shared_ptr<volume<char> > objmask;
     if (clp->UseObjMask(1)) objmask = make_mask(clp->ObjMask(),InclusiveMask,*obj,clp->UseImplicitObjMask(),clp->ImplicitObjValue());
     else objmask = make_mask(clp->ObjMask(),IgnoreMask,*obj,clp->UseImplicitObjMask(),clp->ImplicitObjValue());
 
-    // Normalise obj to global mean 100
-    objmean = spmlike_mean(*obj);
-    (*obj) *= (100.0/objmean);          
-
     // Initialise the field that describes the warps.
     std::vector<boost::shared_ptr<basisfield> >    field = init_warpfield(*clp);
 
@@ -111,7 +175,8 @@ int main(int   argc,
     cf->SetLevel(1);
     cf->SetIntensityMappingFixed(!clp->EstimateIntensity(1));
     cf->SetHessianPrecision(clp->HessianPrecision());
-    if (clp->WeightLambdaBySSD()) cf->WeightLambdaBySSD();
+    cf->SetInterpolationModel(clp->InterpolationModel());
+    if (clp->WeightLambdaBySSD()) cf->WeightLambdaBySSD(); 
     if (clp->UseRefDeriv()) cf->UseRefDerivs();
     if (clp->Debug()) cf->SetDebug(clp->Debug());
 
@@ -187,11 +252,11 @@ int main(int   argc,
       if (clp->ObjFWHM(ssl) != clp->ObjFWHM(ssl-1)) cf->SmoothObj(clp->ObjFWHM(ssl));
 
       // New subsampling
-      cout << "Setting subsampling" << endl;
+      if (clp->Verbose()) cout << "Setting subsampling" << endl;
       if (clp->SubSampling(ssl) != clp->SubSampling(ssl-1)) cf->SubsampleRef(clp->SubSampling(ssl));
-      cout << "Setting reg mode" << endl;
+      if (clp->Verbose()) cout << "Setting reg mode" << endl;
       cf->SetRegularisationModel(clp->RegularisationModel());
-      cout << "Setting lambda" << endl;
+      if (clp->Verbose()) cout << "Setting lambda" << endl;
       cf->SetLambda(clp->Lambda(ssl));  // New (possibly) lambda
       cf->SetMatchingPointsLambda(clp->MatchingPointsLambda(ssl));
       cf->SetIntensityMappingFixed(!clp->EstimateIntensity(ssl));
@@ -203,7 +268,7 @@ int main(int   argc,
 
       // MISCMATHS::NonlinOut status = nonlin(*nlpar,*cf);
       nonlin(*nlpar,*cf);
-      if (!constrain_warpfield(*cf,*clp,5)) { // N.B. arbitrary number 5
+      if (!constrain_warpfield(*cf,*clp,10)) { // N.B. arbitrary number 10
         std::pair<double,double> range = cf->JacobianRange();
         cout << "Warning, Jacobian not within prescribed range. Prescription is " << clp->JacLowerBound() << " -- " << clp->JacUpperBound();
         cout << " and obtained range is " << range.first << " -- " << range.second << endl;
