@@ -265,16 +265,16 @@ class MelodicOptions {
 	   false, no_argument, false),
    migp(string("--migp"), false,
 	   string("switch on MIGP data reduction"),
-	   false, no_argument, false),	
+	   false, no_argument),	
    migpN(string("--migpN"), 0,
 	   string("Number of internal Eigenmaps"),
-	   false, requires_argument, false),
+	   false, requires_argument),
    migp_shuffle(string("--migp_shuffle"), true,
 	   string("Randomise MIGP file order (default: TRUE)"),
-	   false, no_argument, false),
+	   false, no_argument),
    migp_factor(string("--migp_factor"), 2,
 	   string("Internal Factor of mem-threshold relative to number of Eigenmaps (default: 2)"),
-       false, requires_argument, false),
+       false, requires_argument),
    dr(string("--dr"), false,
 	   string("Dual Regression (default: false)"),
 	   false, no_argument, false),
