@@ -83,12 +83,96 @@ using namespace mesh;
 using namespace PARTICLE;
 
 
+
+  class MatCell_cmpr{
+    // This class contains compressed information on entries for matrix4 format
+  public:
+    MatCell_cmpr():code2(0) {}
+    MatCell_cmpr(double val):code2(0) { }
+    MatCell_cmpr(const MatCell_cmpr& rhs){ *this=rhs; }
+    void add_one(float dist,int fib); 
+    void add_n(float dist,vector<float> props,int n);
+    void add_n(int64_t newcode2);
+    int64_t getcode2() const { return code2; }
+    MatCell_cmpr& operator=(const MatCell_cmpr& rhs){
+      code2=rhs.code2;
+      return *this;
+    }
+    MatCell_cmpr& operator+=(const MatCell_cmpr& rhs){      
+      add_n(rhs.code2);
+      return *this;
+    }
+    void Print(){
+      int nsamples, fibcnt1, fibcnt2; float length_tot;
+      decode(code2,nsamples, fibcnt1, fibcnt2, length_tot);
+      cout<<"code2 = "<<code2<<endl;
+      cout<<"nsamples = "<<nsamples<<endl;
+      cout<<"fibcnt1  = "<<fibcnt1<<endl;
+      cout<<"fibcnt2  = "<<fibcnt2<<endl;
+      cout<<"fibcnt3  = "<<nsamples-fibcnt1-fibcnt2<<endl;
+      cout<<"length_tot = "<<length_tot<<endl;
+      cout<<"avg_length = "<<(nsamples!=0?length_tot/(float)nsamples:0.0)<<endl;
+      cout<<"----------------------"<<endl;
+    }
+ 
+  private:
+    int64_t code2; //Compressed info on fibre_count, fibre1_prop, fibre1_prop, avg_length: code2 = two32*fibre_count + mult*mult*fibre_prop1 + mult*fibre_prop2 + length_val
+    void decode(int64_t incode, int& nsamples, int& fibcnt1, int& fibcnt2, float& length_tot) const;
+    void encode(const int nsamples, const int fibcnt1, const int fibcnt2, const float length_tot);
+  };
+  inline MatCell_cmpr operator*(const double& x, const MatCell_cmpr& rhs){ return rhs;}
+  
+
+
+  class SpMatHCPException: public std::exception{
+  private:
+    std::string m_msg;
+  public:
+    SpMatHCPException(const std::string& msg) throw(): m_msg(msg){ }
+    virtual const char * what() const throw() { return string("SpMat_HCP::" + m_msg).c_str(); }
+    ~SpMatHCPException() throw() {}
+  };
+
+
+
+  class SpMat_HCP : public SpMat<MatCell_cmpr>{
+    public:
+    SpMat_HCP():SpMat<MatCell_cmpr>::SpMat(){}
+    SpMat_HCP(unsigned int m, unsigned int n):SpMat<MatCell_cmpr>::SpMat(m,n){}
+    SpMat_HCP(unsigned int m, unsigned int n,const string& basename);
+    ~SpMat_HCP(){}
+    int SaveTrajFile(const string& basename)const;
+    void AddToTraj(unsigned int r,unsigned int c, float dist,int fib){ here(r,c).add_one(dist,fib); } 
+    void AddToTraj(unsigned int r,unsigned int c, float dist, vector<float> props, int n){ here(r,c).add_n(dist,props,n); }
+    void AddToTraj(unsigned int r,unsigned int c, int64_t Newcode2){ here(r,c).add_n(Newcode2); }
+    
+    void Print(){
+      for(unsigned int c=0;c<Ncols();c++){
+	const std::vector<unsigned int>&    ri = get_ri(c);
+	for (unsigned int r=0; r<ri.size(); r++) { 	  
+	  cout<<"Element " << ri[r]+1 <<","<<c+1<<endl;
+	  Peek(ri[r]+1,c+1).Print();
+	}
+      }
+    }
+    void Print(int r,int c){
+      Peek(r,c).Print();
+    }
+  };
+
+
+/*
+  //Old SpMat_HCP with MattCell (less rounding errors, but takes ~5 times as much memory and ~40% more execution time
+
   class MatCell{
     // This class contains information on entries for matrix4 format
   public:
     MatCell():nsamples(0),length_tot(0.0){fibcnt.clear();fibcnt.resize(3,0);}
     MatCell(double val):nsamples(0),length_tot(0.0){fibcnt.clear();fibcnt.resize(3,0);}
-    float   get_avg_length()const{return (length_tot/(float)nsamples);}
+    float   get_avg_length()const{
+      return (nsamples!=0?length_tot/(float)nsamples:0.0);
+    }
+    float   get_length_tot()const{return length_tot;}
     int     get_nsamples()const{return nsamples;}
     float   get_fibprop(const int& f)const{return float(fibcnt[f-1])/float(nsamples);}
     float   get_fibcnt(const int& f)const{return fibcnt[f-1];}
@@ -97,7 +181,20 @@ using namespace PARTICLE;
       length_tot+=dist;
       nsamples+=1;      
     }
-    void print()const{
+    void    add_n(float dist,vector<float> props,int n){
+      if(fibcnt.size()!=3){
+	cerr<<"MatCell::add_n:Only valid with 3 fibres"<<endl;
+	exit(1);
+      }
+      int n0=(int)round(props[0]*n);
+      int n1=(int)round(props[1]*n);
+      fibcnt[0]+=n0;
+      fibcnt[1]+=n1;
+      fibcnt[2]+=(n-n0-n1);
+      length_tot+=(dist*n);
+      nsamples+=n;      
+    }
+    void Print(){
       cout<<"nsamples   = "<<nsamples<<endl;
       cout<<"fibcnt[0]  = "<<fibcnt[0]<<endl;
       cout<<"fibcnt[1]  = "<<fibcnt[1]<<endl;
@@ -115,34 +212,48 @@ using namespace PARTICLE;
       length_tot=rhs.length_tot;
       return *this;
     }
+    MatCell& operator+=(const MatCell& rhs){      
+      length_tot += rhs.get_length_tot();
+      nsamples   += rhs.get_nsamples();
+      for(unsigned int i=0;i<fibcnt.size();i++)
+	fibcnt[i] += rhs.get_fibcnt(i+1);     
+      return *this;
+    }
   private:
     vector<int> fibcnt;
     int         nsamples;
     float       length_tot;
   };
+  inline MatCell operator*(const double& x, const MatCell& rhs){return rhs;}
 
-  class SpMat_HCP : public SpMat<MatCell>
-  {
+  class SpMat_HCP : public SpMat<MatCell>{
     public:
     SpMat_HCP():SpMat<MatCell>::SpMat(){}
     SpMat_HCP(unsigned int m, unsigned int n):SpMat<MatCell>::SpMat(m,n){}
+    SpMat_HCP(unsigned int m, unsigned int n,const string& basename);
     ~SpMat_HCP(){}
     // HCP Trajectory-file writer (MJ+SJ)
     int SaveTrajFile(const string& basename)const;
-    void AddToTraj(unsigned int r,unsigned int c,
-		   float dist,int fib){
-      //MatCell mc=this->Peek(r,c);     
-      //mc.add_one(dist,fib);
-      //Set(r,c,mc);
-      
-      here(r,c).add_one(dist,fib);
-      //Set(r,c,this->Peek(r,c).add_one(dist,fib));
-    } 
-    //  private:
-    //MatCell mc;
+    void AddToTraj(unsigned int r,unsigned int c, float dist,int fib){ here(r,c).add_one(dist,fib); } 
+    void AddToTraj(unsigned int r,unsigned int c, float dist, vector<float> props, int n){ here(r,c).add_n(dist,props,n); }
     
+    void Print(){
+      for(unsigned int c=0;c<Ncols();c++){
+	const std::vector<unsigned int>&    ri = get_ri(c);
+	for (unsigned int r=0; r<ri.size(); r++) { 	  
+	  cout<<"Element " << ri[r]+1 <<","<<c+1<<endl;
+	  here(ri[r]+1,c+1).Print();
+	}
+      }
+    }
+    void Print(int r,int c){
+      here(r,c).Print();
+    }
   };
 
+*/
+
+
 namespace TRACT{
 
   void read_ascii_files(const string& filename,vector<string>& content);  
@@ -175,14 +286,22 @@ namespace TRACT{
     CSV                           m_netmasks;
 
     vector<int>                   m_way_passed_flags;
+
+    // for network mode
+    int                           m_seed_id;
+    Matrix                        m_network_mat;
     ColumnVector                  m_net_passed_flags;
     //vector<int>                   m_net_passed_flags;
 
+
+    vector< vector<ColumnVector> > m_crossedvox;
+    bool                           m_surfexists;
+
     string                        m_waycond;
     
     volume4D<float>               m_prefdir;
     volume4D<float>               m_loopcheck;
-
+    volume<float>                 m_loccurvthresh;
 
     // transform seed<->diff space
     Matrix                        m_Seeds_to_DTI;
@@ -224,6 +343,11 @@ namespace TRACT{
     const vector<ColumnVector>& get_diff_path_ref() const{return m_diff_path;}
     vector<ColumnVector>        get_diff_path()     const{return m_diff_path;}
 
+    vector< vector<ColumnVector> >        get_crossedvox()const{return m_crossedvox;}
+    const vector< vector<ColumnVector> >& get_crossedvox_ref()const{return m_crossedvox;}
+
+    void surfexists(){m_surfexists=true;}
+
     inline void reset(){
       m_part.reset();
       vols.reset(opts.fibst.value());
@@ -275,7 +399,7 @@ namespace TRACT{
       m_netmasks.reinitialize(m_seeds.get_refvol());
       m_netmasks.set_convention(opts.meshspace.value());
       m_netmasks.load_rois(tmpfilename);    
-
+      if(m_netmasks.nSurfs()>0){surfexists();}
       m_net_passed_flags.ReSize(m_netmasks.nRois());
       m_net_passed_flags=0;
 
@@ -283,11 +407,28 @@ namespace TRACT{
       //m_net_passed_flags.resize(m_netmasks.nRois(),0);
 
     }
+    void set_seed_id(const int i){m_seed_id=i;}
+    void init_network_mat(const int n){
+      m_network_mat.ReSize(n,n);
+      m_network_mat=0;
+    }
+    void update_mat(){
+      for(int i=1;i<=m_net_passed_flags.Nrows();i++){
+	if(m_net_passed_flags(i)==0){continue;}
+	if(m_seed_id+1>i){m_network_mat(m_seed_id+1,i)++;}
+	else{m_network_mat(m_seed_id+1,i+1)++;}    
+      }   
+    }
+    void save_network_mat(){
+      write_ascii_matrix(m_network_mat,logger.appendDir("fdt_network_matrix"));
+    }
+    const ColumnVector& net_passed_flags(){return m_net_passed_flags;}
+
     void load_waymasks(const string& filename){
       m_waymasks.reinitialize(m_seeds.get_refvol());
       m_waymasks.set_convention(opts.meshspace.value());
       m_waymasks.load_rois(filename);    
-
+      if(m_waymasks.nSurfs()>0){surfexists();}
       m_way_passed_flags.clear(); 
       for(int i=0;i<m_waymasks.nRois();i++)
 	m_way_passed_flags.push_back(0);
@@ -300,11 +441,13 @@ namespace TRACT{
       m_stop.reinitialize(m_seeds.get_refvol());
       m_stop.set_convention(opts.meshspace.value());
       m_stop.load_rois(filename);     
+      if(m_stop.nSurfs()>0){surfexists();}
     }
     void load_rubbish(const string& filename){      
       m_rubbish.reinitialize(m_seeds.get_refvol());
       m_rubbish.set_convention(opts.meshspace.value());
       m_rubbish.load_rois(filename);     
+      if(m_rubbish.nSurfs()>0){surfexists();}
     }
 
     // //////    matrix3 methods
@@ -312,11 +455,13 @@ namespace TRACT{
       m_mask3.reinitialize(m_seeds.get_refvol());
       m_mask3.set_convention(opts.meshspace.value());
       m_mask3.load_rois(opts.mask3.value());
+      if(m_mask3.nSurfs()>0){surfexists();}
 
       if(opts.lrmask3.value()!=""){
 	m_lrmask3.reinitialize(m_seeds.get_refvol());
 	m_lrmask3.set_convention(opts.meshspace.value());      
 	m_lrmask3.load_rois(opts.lrmask3.value());
+	if(m_lrmask3.nSurfs()>0){surfexists();}
       }
     }
     void                       clear_inmask3()   {m_inmask3.clear();}
@@ -359,9 +504,16 @@ namespace TRACT{
     Matrix                       m_I;
     vector<ColumnVector>         m_path;
     vector<ColumnVector>         m_diff_path;
+    vector< vector<ColumnVector> > m_crossedvox;
     CSV                          m_prob_alt;  // spatial histogram of tracts with alternative user-defined mask
     CSV                          m_beenhere_alt;
 
+    // same as m_prob and m_localdir but split into the different
+    // target masks if the option opts.targetpaths is ON
+    vector< volume<float> >      m_prob_multi;
+    vector< volume4D<float> >    m_localdir_multi;
+    
+
     // temp 
     volume<float>                m_lastpoint; // store last point in trajectory
 
@@ -384,6 +536,7 @@ namespace TRACT{
     CSV                          m_s2t_count;
     Matrix                       m_s2tastext;
     int                          m_s2trow;
+    volume4D<float>              m_targetpaths;
 
     // MATRIX 1
     SpMat<float>                *m_ConMat1; // using sparse
@@ -401,8 +554,9 @@ namespace TRACT{
     vector<int>                  m_inmask3;
 
     // MATRIX 4 - columns are seed space, rows are diffusion space
-    SpMat_HCP               *m_ConMat4;     
+    SpMat_HCP                   *m_ConMat4;     
     volume<int>                  m_dtimask;
+    CSV                          m_mask4;
     volume<int>                  m_lookup4;
     volume<int>                  m_beenhere4;
     ColumnVector                 m_dtidim;
@@ -442,20 +596,16 @@ namespace TRACT{
 			  m_stline.get_seeds().ysize(),
 			  m_stline.get_seeds().zsize());
       copybasicproperties(m_stline.get_seeds().get_refvol(),m_prob);
-      m_prob=0;
-      // m_lastpoint.reinitialize(m_stline.get_seeds().xsize(),
-      // 			       m_stline.get_seeds().ysize(),
-      // 			       m_stline.get_seeds().zsize());
-      // copybasicproperties(m_stline.get_seeds().get_refvol(),m_lastpoint);
-      // m_lastpoint=0;
-      
+      m_prob=0;      
       if(opts.opathdir.value()){
 	m_localdir.reinitialize(m_stline.get_seeds().xsize(),
 				m_stline.get_seeds().ysize(),
-				m_stline.get_seeds().zsize(),3);
+				m_stline.get_seeds().zsize(),6);
 	copybasicproperties(m_stline.get_seeds().get_refvol(),m_localdir);
 	m_localdir=0;
       }
+      
+
       if(opts.pathfile.set()){
 	m_prob_alt.reinitialize(m_stline.get_seeds().get_refvol());
 	m_prob_alt.set_convention(opts.meshspace.value());
@@ -465,6 +615,7 @@ namespace TRACT{
 	m_beenhere_alt.set_convention(opts.meshspace.value());
 	m_beenhere_alt.load_rois(opts.pathfile.value());
 	m_beenhere_alt.set_vol_values(1);
+	if(m_prob_alt.nSurfs()>0){m_stline.surfexists();}
       }
       if(opts.verbose.value()>0)
 	cout<<"....done"<<endl;
@@ -483,6 +634,7 @@ namespace TRACT{
       m_path=m_stline.get_path();
       if(opts.matrix4out.value())
 	m_diff_path=m_stline.get_diff_path();
+      m_crossedvox=m_stline.get_crossedvox();
     }
     void append_path(){      
       for(unsigned int i=0;i<m_stline.get_path_ref().size();i++){
@@ -490,12 +642,22 @@ namespace TRACT{
 	if(opts.matrix4out.value())
 	  m_diff_path.push_back(m_stline.get_diff_path_ref()[i]);
       }
+      for(unsigned int i=0;i<m_stline.get_crossedvox_ref().size();i++){
+	m_crossedvox.push_back(m_stline.get_crossedvox_ref()[i]);
+      }
     }
     float calc_pathlength(const int& redund=0){
       return( float(m_path.size()-redund)*opts.steplength.value() );
     }
 
-    void clear_path(){ m_path.clear(); if(opts.matrix4out.value())m_diff_path.clear(); };
+    void clear_path(){ 
+      m_path.clear(); 
+      if(opts.matrix4out.value()){
+	m_diff_path.clear(); 
+      }      
+      m_crossedvox.clear();
+      
+    };
 
     void count_streamline();
     void count_seed();
@@ -504,6 +666,7 @@ namespace TRACT{
     
     void update_pathdist();
     void reset_beenhere();
+    void update_pathdist_multi();
     
     void reset_prob(){m_prob=0;}
     void update_seedcounts();
