@@ -3,10 +3,70 @@
  *  
  *
  *  Created by Brian Patenaude on 23/06/2008.
- *  Copyright 2008 __MyCompanyName__. All rights reserved.
+ *  Copyright 2008 University of Oxford All rights reserved.
  *
  */
-
+/*  Part of FSL - FMRIB's Software Library
+    http://www.fmrib.ox.ac.uk/fsl
+    fsl@fmrib.ox.ac.uk
+    
+    Developed at FMRIB (Oxford Centre for Functional Magnetic Resonance
+    Imaging of the Brain), Department of Clinical Neurology, Oxford
+    University, Oxford, UK
+    
+    
+    LICENCE
+    
+    FMRIB Software Library, Release 5.0 (c) 2012, The University of
+    Oxford (the "Software")
+    
+    The Software remains the property of the University of Oxford ("the
+    University").
+    
+    The Software is distributed "AS IS" under this Licence solely for
+    non-commercial use in the hope that it will be useful, but in order
+    that the University as a charitable foundation protects its assets for
+    the benefit of its educational and research purposes, the University
+    makes clear that no condition is made or to be implied, nor is any
+    warranty given or to be implied, as to the accuracy of the Software,
+    or that it will be suitable for any particular purpose or for use
+    under any specific conditions. Furthermore, the University disclaims
+    all responsibility for the use which is made of the Software. It
+    further disclaims any liability for the outcomes arising from using
+    the Software.
+    
+    The Licensee agrees to indemnify the University and hold the
+    University harmless from and against any and all claims, damages and
+    liabilities asserted by third parties (including claims for
+    negligence) which arise directly or indirectly from the use of the
+    Software or the sale of any products based on the Software.
+    
+    No part of the Software may be reproduced, modified, transmitted or
+    transferred in any form or by any means, electronic or mechanical,
+    without the express permission of the University. The permission of
+    the University is not required if the said reproduction, modification,
+    transmission or transference is done without financial return, the
+    conditions of this Licence are imposed upon the receiver of the
+    product, and all original and amended source code is included in any
+    transmitted product. You may be held legally responsible for any
+    copyright infringement that is caused or encouraged by your failure to
+    abide by these terms and conditions.
+    
+    You are not permitted under this Licence to use this Software
+    commercially. Use for which any financial return is received shall be
+    defined as commercial use, and includes (1) integration of all or part
+    of the source code or the Software into a product for sale or license
+    by or on behalf of Licensee to third parties or (2) use of the
+    Software or any derivative of it for research with the final aim of
+    developing software products for sale or license to a third party or
+    (3) use of the Software or any derivative of it for research with the
+    final aim of developing non-software products for sale or license to a
+    third party, or (4) use of the Software to provide any service to an
+    external organisation for which payment is received. If you are
+    interested in using the Software commercially, please contact Isis
+    Innovation Limited ("Isis"), the technology transfer company of the
+    University, to negotiate a licence. Contact details are:
+    innovation@isis.ox.ac.uk quoting reference DE/9564. */
 #include "shapeModel.h"
 #include <iostream>
 #include <string>
@@ -16,7 +76,7 @@
 //#include <vector>
  #include "newmat.h"
  #include "newmatap.h"
-
+#include "fslvtkio/fslvtkio.h"
 #include "first_lib/first_newmat_vec.h"
 #include <cmath>
 #include <algorithm>
@@ -24,6 +84,7 @@
 using namespace std;
 using namespace NEWMAT;
 using namespace FIRST_LIB;
+using namespace fslvtkio;
 namespace SHAPE_MODEL_NAME{
 	
 	shapeModel::shapeModel()
@@ -250,7 +311,7 @@ vector<float> shapeModel::getDeformedIGrid( const vector<float> & vars) const {
 		
 			smodes= first_newmat_vector::matrixToVector<float>((U*U2).SubMatrix(1,U.Nrows(),1,D2.Nrows()));
 			vector<float> veigs, vsqrt_eigs;
-			for (unsigned int i=0;i<D2.Nrows();i++)//static_cast<unsigned int>(D2.Nrows());i++)
+			for (unsigned int i=0;i<static_cast<unsigned int>(D2.Nrows());i++)//static_cast<unsigned int>(D2.Nrows());i++)
 			{
 				veigs.push_back(D2.element(i));
 				vsqrt_eigs.push_back(sqrt(D2.element(i)));
@@ -325,6 +386,86 @@ vector<float> shapeModel::getDeformedIGrid( const vector<float> & vars) const {
 		}
 		return bvars_orig;
 	}
-
+	
+	
+	shapeModel* shapeModel::loadAndCreateShapeModel( const string & modelname, const bool & verbose)
+	{
+		
+		if (verbose) cout<<"read model"<<endl;
+		fslvtkIO* fmodel = new fslvtkIO(modelname,static_cast<fslvtkIO::DataType>(0));
+		if (verbose) cout<<"done reading model"<<endl;
+		const int Npts=fmodel->getPointsAsMatrix().Nrows();
+		
+		
+		if (verbose) cout<<"setting up shape/appearance model"<<endl;
+		
+		//load mean shape into vector
+		vector<float> Smean;
+		Matrix* Pts = new Matrix;
+		*Pts=fmodel->getPointsAsMatrix();
+		
+		if (verbose) cout<<"The shape has "<<Npts<<" vertices."<<endl;
+		for (int i=0;i< Npts ; i++){
+			Smean.push_back(Pts->element(i,0));
+			Smean.push_back(Pts->element(i,1));
+			Smean.push_back(Pts->element(i,2));
+		}   
+		Pts->ReleaseAndDelete();
+		
+		//read polygon data
+		vector< vector<unsigned int > > polygons = first_newmat_vector::matrixToVector<unsigned int>(fmodel->getPolygons().t());
+		
+		//process shape modes and conditional intensity mean modes
+		Matrix SmodesM;
+		Matrix ImodesM;
+		
+		
+		SmodesM=first_newmat_vector::unwrapMatrix(fmodel->getField("mode0"));
+		ImodesM=first_newmat_vector::unwrapMatrix(fmodel->getField("Imode0"));
+		unsigned int M = static_cast<unsigned int>(fmodel->getField("numSubjects").element(0,0));
+		if (verbose) cout<<"The model was constructed from "<<M<<" training subjects."<<endl;
+		
+		unsigned int AllModes=M;
+		
+		for (unsigned int i =1; i<AllModes;i++)
+		{
+			stringstream ss;
+			ss<<i;
+			string mode;
+			ss>>mode;
+			SmodesM=SmodesM | first_newmat_vector::unwrapMatrix(fmodel->getField("mode"+mode));
+			ImodesM=ImodesM | first_newmat_vector::unwrapMatrix(fmodel->getField("Imode"+mode));
+			
+		}
+		if (verbose) cout<<AllModes<<" modes of variation are retained."<<endl;
+		
+		
+		vector< vector<float > > Smodes = first_newmat_vector::matrixToVector<float>(SmodesM);
+		vector< vector<float > > Imodes = first_newmat_vector::matrixToVector<float>(ImodesM);
+		ImodesM.Release();
+		SmodesM.Release();
+		
+		
+		//process rest of information, including intensity variance
+		vector< vector<float > > Iprec = first_newmat_vector::matrixToVector<float>(fmodel->getField("iCondPrec0").t());
+		vector<float > Errs =  first_newmat_vector::vectorToVector<float>(fmodel->getField("ErrPriors0"));
+		vector<float > se =  first_newmat_vector::vectorToVector<float>(fmodel->getField("eigenValues"), AllModes);
+		vector<float > ie =  first_newmat_vector::vectorToVector<float>(fmodel->getField("iCondEigs0"));
+		vector<float > Imean =  first_newmat_vector::vectorToVector<float>(first_newmat_vector::unwrapMatrix(fmodel->getField("Imean")));
+		vector<int> labels =  first_newmat_vector::vectorToVector<int>(fmodel->getField("labels"));
+		
+		
+		
+		//have read in all data and store in local structures, now delete the reader.
+		delete fmodel;
+		cout<<"create shapeModel "<<endl;
+		//create shape model
+		shapeModel* model1 = new shapeModel(Smean, Smodes, se, Imean, Imodes,Iprec, ie, M,Errs,polygons,labels);
+		cout<<"done creating shapeModel "<<endl;
+		
+		return model1;
+		
+	}
+	
 	
 }
