@@ -1,4 +1,5 @@
-/*  Copyright (C) 1999-2004 University of Oxford  */
+
+/*  Copyright (C) 1999-2014 University of Oxford  */
 
 /*  Part of FSL - FMRIB's Software Library
     http://www.fmrib.ox.ac.uk/fsl
@@ -167,7 +168,7 @@ namespace Utilities {
   }
  
   unsigned int OptionParser::parse_command_line(unsigned int argc, 
-						char **argv, int skip) 
+						char **argv, int skip, bool silentFail) 
   {
     unsigned int optpos = 1 + skip;
     unsigned int valpos = 1 + skip;
@@ -177,9 +178,14 @@ namespace Utilities {
       unsigned int increments = 0;
       
       string optstr(argv[optpos]), valstr;
-
-      if(optstr[0] != '-')	// End of parsable options
-	break;
+   
+      if(optstr[0] != '-') {	// End of parsable options
+	
+	if (!silentFail) // Throwing an error if an unrecognised token occurs in the command line
+	  throw X_OptionError(optstr, " is an unrecognised token");
+	else // if silentFail is TRUE then ignores an unrecognised token and continues
+	  break;
+      }
 
       if(optstr[1] == '-') {	// Parse a long opt
 
