@@ -106,17 +106,17 @@ FnirtFileReader::FnirtFileReader(const FnirtFileReader& src)
     if (_type == FnirtSplineDispType) {
       if (src._coef_rep[i]) {
         const splinefield& tmpref = dynamic_cast<const splinefield&>(*(src._coef_rep[i]));
-        _coef_rep[i] = shared_ptr<basisfield>(new splinefield(tmpref));
+        _coef_rep[i] = boost::shared_ptr<basisfield>(new splinefield(tmpref));
       }
     }
     if (_type == FnirtDCTDispType) {
       if (src._coef_rep[i]) {
         const dctfield& tmpref = dynamic_cast<const dctfield&>(*(src._coef_rep[i]));
-        _coef_rep[i] = shared_ptr<basisfield>(new dctfield(tmpref));
+        _coef_rep[i] = boost::shared_ptr<basisfield>(new dctfield(tmpref));
       }
     }
   }
-  if (src._vol_rep) _vol_rep = shared_ptr<volume4D<float> >(new volume4D<float>(*(src._vol_rep)));
+  if (src._vol_rep) _vol_rep = boost::shared_ptr<volume4D<float> >(new volume4D<float>(*(src._vol_rep)));
 }
 
 /////////////////////////////////////////////////////////////////////
@@ -351,7 +351,7 @@ splinefield FnirtFileReader::FieldAsSplinefield(unsigned int indx, vector<unsign
     else {
       if (!order || order==SplineOrder()) {  // If we are keeping the order
         order = SplineOrder();
-        shared_ptr<basisfield>  tmpptr = _coef_rep[indx]->ZoomField(FieldSize(),VoxelSize(),ksp);
+        boost::shared_ptr<basisfield>  tmpptr = _coef_rep[indx]->ZoomField(FieldSize(),VoxelSize(),ksp);
         const splinefield&      tmpref = dynamic_cast<const splinefield&>(*tmpptr);
         return(tmpref);
       }
@@ -384,15 +384,15 @@ dctfield FnirtFileReader::FieldAsDctfield(unsigned int indx, vector<unsigned int
     throw FnirtFileReaderException("FieldAsDctfield: Must specify order if DCT is not native type");
   }
   if (indx > 2) throw FnirtFileReaderException("FieldAsSplineField: indx out of range");
-  shared_ptr<volume<float> >   volp;
-  shared_ptr<dctfield>         rvalp;
+  boost::shared_ptr<volume<float> >   volp;
+  boost::shared_ptr<dctfield>         rvalp;
   if (_type == FnirtDCTDispType) {
     if (!order.size() || order==DCTOrder()) {
       const dctfield& tmpref = dynamic_cast<const dctfield&>(*(_coef_rep[indx]));
       return(tmpref);
     }
     else {
-      shared_ptr<basisfield>  tmpptr = _coef_rep[indx]->ZoomField(FieldSize(),VoxelSize(),order);
+      boost::shared_ptr<basisfield>  tmpptr = _coef_rep[indx]->ZoomField(FieldSize(),VoxelSize(),order);
       const dctfield& tmpref = dynamic_cast<const dctfield&>(*tmpptr);
       return(tmpref);
     }
@@ -627,12 +627,12 @@ void FnirtFileReader::common_read(const string& fname, AbsOrRelWarps wt, bool ve
     _aor = RelativeWarps;                                               // Relative warps
     _aff = estimate_affine_part(vol);                                   // Get (possible) affine component
     for (int i=0; i<3; i++) remove_affine_part(_aff,i,vol[i]);          // Siphon off the affine component
-    _vol_rep = shared_ptr<volume4D<float> >(new volume4D<float>(vol));  // Represent as volume
+    _vol_rep = boost::shared_ptr<volume4D<float> >(new volume4D<float>(vol));  // Represent as volume
     break;
   default:                                                              // Field generated by "unknown" application
     _type = UnknownDispType;
     _aor =wt;                                                           // Trust the user
-    _vol_rep = shared_ptr<volume4D<float> >(new volume4D<float>(vol));  // Represent as volume
+    _vol_rep = boost::shared_ptr<volume4D<float> >(new volume4D<float>(vol));  // Represent as volume
     _aff = IdentityMatrix(4);                                           // Affine part already included
     // Convert into relative warps (if neccessary)
     if (wt==AbsoluteWarps) convertwarp_abs2rel(*_vol_rep);
@@ -659,7 +659,7 @@ void FnirtFileReader::common_read(const string& fname, AbsOrRelWarps wt, bool ve
   }
 }
 
-vector<shared_ptr<basisfield> > FnirtFileReader::read_coef_file(const volume4D<float>&   vcoef,
+vector<boost::shared_ptr<basisfield> > FnirtFileReader::read_coef_file(const volume4D<float>&   vcoef,
                                                                 bool                     verbose) const
 {
   // Collect info that we need to create the fields
@@ -674,7 +674,7 @@ vector<shared_ptr<basisfield> > FnirtFileReader::read_coef_file(const volume4D<f
   if (verbose) cout << "Matrix size: " << sz[0] << "  " << sz[1] << "  " << sz[2] << endl;
   if (verbose) cout << "Voxel size: " << vxs[0] << "  " << vxs[1] << "  " << vxs[2] << endl;
 
-  vector<shared_ptr<basisfield> >   fields(3);
+  vector<boost::shared_ptr<basisfield> >   fields(3);
 
   if (vcoef.intent_code() == FSL_CUBIC_SPLINE_COEFFICIENTS ||
       vcoef.intent_code() == FSL_QUADRATIC_SPLINE_COEFFICIENTS) {        // Interpret as spline coefficients
@@ -688,7 +688,7 @@ vector<shared_ptr<basisfield> > FnirtFileReader::read_coef_file(const volume4D<f
     if (verbose) cout << "Knot-spacing: " << ksp[0] << "  " << ksp[1] << "  " << ksp[2] << endl;
     if (verbose) cout << "Size of coefficient matrix: " << vcoef.xsize() << "  " << vcoef.ysize() << "  " << vcoef.zsize() << endl;
     for (int i=0; i<3; i++) {
-      fields[i] = shared_ptr<splinefield>(new splinefield(sz,vxs,ksp,order));
+      fields[i] = boost::shared_ptr<splinefield>(new splinefield(sz,vxs,ksp,order));
     }
     // Sanity check
     if (fields[0]->CoefSz_x() != static_cast<unsigned int>(vcoef.xsize()) ||
@@ -705,7 +705,7 @@ vector<shared_ptr<basisfield> > FnirtFileReader::read_coef_file(const volume4D<f
     order[2] = static_cast<unsigned int>(vcoef.zsize());
     if (verbose) cout << "Size of coefficient matrix: " << vcoef.xsize() << "  " << vcoef.ysize() << "  " << vcoef.zsize() << endl;
     for (int i=0; i<3; i++) {
-      fields[i] = shared_ptr<dctfield>(new dctfield(sz,vxs,order));
+      fields[i] = boost::shared_ptr<dctfield>(new dctfield(sz,vxs,order));
     }
   }
 
